Extends Clojure core with the implementations of fluokitten protocols. Defines curried functions. Need to be used or required for enabling Fluokitten on projects that run on JVM platform.
Extends Clojure core with the implementations of fluokitten protocols. Defines curried functions. Need to be used or required for enabling Fluokitten on projects that run on JVM platform.
(array-fapply atype etype)(array-fapply atype etype eclass)(array-fapply atype etype res gs & as)(array-fmap atype etype)(array-fmap atype etype eclass)(array-fmap atype etype res f & as)(curried-op)(curried-op x)(curried-op x y)(curried-op x y z)(curried-op x y z w)(curried-op x y z w ws)(num-array-foldmap atype etype)(num-array-foldmap atype etype f g init & as)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |